@@ -15,7 +15,7 @@ extensions = ["myst_nb", "sphinx_thebe"]
 html_theme = "sphinx_book_theme"
 html_copy_source = True
 html_sourcelink_suffix = ""
-jupyter_execute_notebooks = "auto"
+nb_execution_mode = "auto"
 
 # Base options, we can add other key/vals later
 html_theme_options = {
@@ -26,7 +26,9 @@ html_theme_options = {
         "binderhub_url": "https://mybinder.org",
         "jupyterhub_url": "https://datahub.berkeley.edu",
         "colab_url": "https://colab.research.google.com",
+        "deepnote_url": "https://deepnote.com",
         "notebook_interface": "jupyterlab",
         "thebe": True,
     },
+    "navigation_with_keys": True,
 }
